@@ -1,10 +1,11 @@
 from .make_abuse import generate_random_abuse
 
 
-def main():
+def abuse() -> str:
     random_abuse = generate_random_abuse()
-    print(random_abuse)
+    return random_abuse
 
 
 if __name__ == '__main__':
-    main()
+    print(abuse())
+
